@@ -4,6 +4,7 @@ import time
 import yaml
 import base64
 
+# This class will No longer be supported in version 4+ of the API
 class simulation:
 
     def __init__(self,token,simPath,numImages,user,nodes,name,descript,seed):
@@ -80,10 +81,13 @@ class simulation:
         }
 
         response = requests.request("GET", url, headers=headers, data=payload)
-
-        #update if sim is complete or not complete
-        parseResponse = json.loads(response.text)
-        self.isComplete = parseResponse["isComplete"]
+        response_code = response.status_code
+        if response_code == 401:
+            return("Unauthorized")
+        if response_code == 200:
+            #update if sim is complete or not complete
+            parseResponse = json.loads(response.text)
+            self.isComplete = parseResponse["isComplete"]
 
     def getProgress(self):
         url = "https://lexsetapi.azurewebsites.net/api/simulations/getstatus?id=" + str(self.simID)
@@ -159,11 +163,16 @@ def getDatasetID(id,userToken):
 
     response = requests.request("GET", url, headers=headers, data=payload)
 
-    #print(response.text)
-    parseResponse = json.loads(response.text)
-    #print("Response:")
-    #print(response.text)
-    return parseResponse["datasets"][0]["id"]
+    getCode = response.status_code
+
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        parseResponse = json.loads(response.text)
+        return parseResponse["datasets"][0]["id"]
+    else:
+        print("Error: " + str(getCode))
+        return(getCode)
 
 def listSimulations(id,userToken):
     url = "https://lexsetapi.azurewebsites.net/api/simulations/GetActiveSimulations/?userid=" + str(id)
@@ -175,34 +184,34 @@ def listSimulations(id,userToken):
 
     response = requests.request("GET", url, headers=headers, data=payload)
 
-    #print(response.text)
-    parseResponse = json.loads(response.text)
-    #print("Response:")
-    #print(response.text)
-    simulations = parseResponse
-    return(simulations)
+    getCode = response.status_code
+
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        parseResponse = json.loads(response.text)
+        return(parseResponse)
+    else:
+        print("Error: " + str(getCode))
+        return(getCode)
 
 def addRule(userID,configFile,userToken):
-
+    # Remove in future versions
     url = "https://lexsetapi.lexset.ai/api/UserDataManagement/uploaduserfile"
 
     payload={'userid': str(userID)}
-    #print(payload)
+
     path = str(configFile)
 
     name = path.split("/")
-    #print(name[len(name)-1])
-
     files=[('files',(str(name[len(name)-1]),open(str(path),'rb'),'application/octet-stream'))]
-
     headers = {'Authorization': 'Bearer ' + str(userToken)}
-
     response = requests.request("POST", url, headers=headers, data=payload, files=files)
 
     print(response.text)
 
 def addColorMap(userID,configFile,userToken):
-
+    # Remove in future versions
     url = "https://lexsetapi.lexset.ai/api/UserDataManagement/uploaduserfile"
 
     payload={'userid': str(userID),'filetype': '1'}
@@ -210,12 +219,9 @@ def addColorMap(userID,configFile,userToken):
     path = str(configFile)
 
     name = path.split("/")
-    #print(name[len(name)-1])
 
     files=[('files',(str(name[len(name)-1]),open(str(path),'rb'),'application/octet-stream'))]
-
     headers = {'Authorization': 'Bearer ' + str(userToken)}
-
     response = requests.request("POST", url, headers=headers, data=payload, files=files)
 
     print(response.text)
@@ -226,9 +232,17 @@ def listUploads(user):
 
     headers = {}
 
-    response = requests.request("GET", url, headers=headers, data=payload)
-    print("uploadedFiles")
-    print(response.text)
+    getCode = requests.status_codes
+
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        response = requests.request("GET", url, headers=headers, data=payload)
+        print("uploadedFiles")
+        print(response.text)
+    else:
+        print("Error: " + str(getCode))
+        return(getCode)
 
 def stop(simulationID,token):
     url = "https://lexsetapi.azurewebsites.net/api/simulations/stopsimulation?id=" + str(simulationID)
@@ -239,8 +253,15 @@ def stop(simulationID,token):
     }
 
     response = requests.request("POST", url, headers=headers, data=payload)
-
-    print(response.text)
+    getCode = response.status_code
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        #parseResponse = json.loads(response.text)
+        return("success")
+    else:
+        print("Error: " + str(getCode))
+        return(getCode)
 
 def start(simulationID,token):
     url = "https://lexsetapi.azurewebsites.net/api/Simulations/StartSimulation?id=" + str(simulationID)
@@ -251,6 +272,16 @@ def start(simulationID,token):
     }
 
     response = requests.request("POST", url, headers=headers, data=payload)
+    
+    getCode = response.status_code
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        #parseResponse = json.loads(response.text)
+        return("success")
+    else:
+        print("Error: " + str(getCode))
+        return(getCode)
 
 def download(datasetID ,userToken, localPath = "NONE"):
     url = "https://lexsetapi.azurewebsites.net/api/datasets/getdatasetarchives?dataset_id=" + str(datasetID)
@@ -264,7 +295,12 @@ def download(datasetID ,userToken, localPath = "NONE"):
 
     #print(response.text)
     parseResponse = json.loads(response.text)
-    if len(parseResponse) > 0:
+
+    getCode = response.status_code
+    if getCode == 401:
+        return("Unauthorized")
+    
+    if getCode == 200:
         datasetURL = parseResponse[0]["url"]
         resp = requests.get(datasetURL, allow_redirects=True)
         if(localPath == "NONE"):
@@ -297,11 +333,15 @@ def getProgress(simID,token):
     }
 
     response = requests.request("GET", url, headers=headers, data=payload)
-
-    #update if sim is complete or not complete
-    parseResponse = json.loads(response.text)
-    print(parseResponse)
-    return parseResponse
+    getCode = response.status_code
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        parseResponse = json.loads(response.text)
+        return(parseResponse)
+    else:
+        print("Error: " + str(getCode))
+        return(getCode)
 
 def getStatus(simID, token):
     url = "https://lexsetapi.azurewebsites.net/api/simulations/getsimulationstatus?id=" + str(simID)
@@ -312,20 +352,25 @@ def getStatus(simID, token):
     }
 
     response = requests.request("GET", url, headers=headers, data=payload)
+    getCode = response.status_code
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        #update if sim is complete or not complete
+        parseResponse = json.loads(response.text)
+        if parseResponse == None:
+            return False
+        else:
+            isComplete = parseResponse["isComplete"]
 
-    #update if sim is complete or not complete
-    parseResponse = json.loads(response.text)
-    if parseResponse == None:
-        return False
+            return(isComplete)
     else:
-        isComplete = parseResponse["isComplete"]
-
-        return(isComplete)
+        print("Error: " + str(getCode))
+        return(getCode)
 
 
 # batch simulation functionality
 
-
 class activateSimulation:
 
     def __init__(self,simID, user, token):
@@ -353,8 +398,15 @@ class activateSimulation:
         }
 
         response = requests.request("POST", url, headers=headers, data=payload)
-        print('NEW JOB STARTED: ' + str(self.simID) + ' has started')
-        print('-------------')
+        getCode = response.status_code
+        if getCode == 401:
+            return("Unauthorized")
+        if getCode == 200:
+            print('NEW JOB STARTED: ' + str(self.simID) + ' has started')
+            print('-------------')
+        else:
+            print("Error: " + str(getCode))
+            return(getCode)
 
     def updateStatus(self):
         url = "https://lexsetapi.azurewebsites.net/api/simulations/getsimulationstatus?id=" + str(self.simID)
@@ -365,12 +417,19 @@ class activateSimulation:
         }
 
         response = requests.request("GET", url, headers=headers, data=payload)
+        getCode = response.status_code
 
-        #update if sim is complete or not complete
-        parseResponse = json.loads(response.text)
-        self.nodeCount = parseResponse["requestedNodeCount"]
-        self.hasStarted = parseResponse["hasStarted"]
-        self.isComplete = parseResponse["isComplete"]
+        if getCode == 401:
+            return("Unauthorized")
+        if getCode == 200:
+            #update if sim is complete or not complete
+            parseResponse = json.loads(response.text)
+            self.nodeCount = parseResponse["requestedNodeCount"]
+            self.hasStarted = parseResponse["hasStarted"]
+            self.isComplete = parseResponse["isComplete"]
+        else:
+            print("Error: " + str(getCode))
+            return(getCode)
 
     def getProgress(self):
         url = "https://lexsetapi.azurewebsites.net/api/simulations/getstatus?id=" + str(self.simID)
@@ -381,11 +440,17 @@ class activateSimulation:
         }
 
         response = requests.request("GET", url, headers=headers, data=payload)
+        getCode = response.status_code
+        if getCode == 401:
+            return("Unauthorized")
+        if getCode == 200:
+            #update if sim is complete or not complete
+            parseResponse = json.loads(response.text)
+            print(parseResponse)
+        else:
+            print("Error: " + str(getCode))
+            return(getCode)
 
-        #update if sim is complete or not complete
-        parseResponse = json.loads(response.text)
-        print(parseResponse)
-        #self.isComplete = parseResponse["isComplete"]
 
     def stopSimulation(self):
         url = "https://lexsetapi.azurewebsites.net/api/simulations/stopsimulation?id=" + str(self.simID)
@@ -396,8 +461,15 @@ class activateSimulation:
         }
 
         response = requests.request("POST", url, headers=headers, data=payload)
+        getCode = response.status_code
 
-        print(response.text)
+        if getCode == 401:
+            return("Unauthorized")  
+        if getCode == 200:
+            print("success")
+        else:
+            print("Error: " + str(getCode))
+            return(getCode)
 
     def downloadData(self):
         url = "https://lexsetapi.azurewebsites.net/api/datasets/getdatasetarchives?dataset_id=" + str(self.dataID)
@@ -408,17 +480,24 @@ class activateSimulation:
         }
 
         response = requests.request("GET", url, headers=headers, data=payload)
+        getCode = response.status_code
 
-        print(response.text)
-        parseResponse = json.loads(response.text)
-        print("Response:")
-        print(response.text)
-        self.datasetURL = parseResponse[0]["url"]
-        if len(parseResponse) > 0:
-            resp = requests.get(self.datasetURL, allow_redirects=True)
-            open('dataset.zip', 'wb').write(resp.content)
+        if getCode == 401:
+            return("Unauthorized")
+        if getCode == 200:
+            print(response.text)
+            parseResponse = json.loads(response.text)
+            print("Response:")
+            print(response.text)
+            self.datasetURL = parseResponse[0]["url"]
+            if len(parseResponse) > 0:
+                resp = requests.get(self.datasetURL, allow_redirects=True)
+                open('dataset.zip', 'wb').write(resp.content)
+            else:
+                return("Dataset zipping")
         else:
-            return("Dataset zipping")
+            print("Error: " + str(getCode))
+            return(getCode)
 
 
 def activeSimulationNodes(userID, token):
@@ -431,20 +510,66 @@ def activeSimulationNodes(userID, token):
 
     response = requests.request("GET", url, headers=headers, data=payload)
 
-    #update if sim is complete or not complete
-    parseResponse = json.loads(response.text)
-    nodes = 0
-
-    y = parseResponse
-
-    for item in range(len(y)):
     
-        if (y[item]['hasStarted']== True) :
-            nodes = nodes + int(y[item]['requestedNodeCount'])
+    parseResponse = json.loads(response.text)
+    getCode = response.status_code
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        #update if sim is complete or not complete
+        nodes = 0
+        y = parseResponse
+
+        for item in range(len(y)):
+        
+            if (y[item]['hasStarted']== True) :
+                nodes = nodes + int(y[item]['requestedNodeCount'])
+
+        return nodes
+    else:
+        print("Error: " + str(getCode))
+        return(getCode)
+
+
+#http request to get compute resources endpoint
+def getComputeResources(id,userToken):
+    url = "https://seahaven.lexset.ai/api/accountusage/GetActiveComputeNodeCount?userid=" + str(id)
+
+    payload={}
+    headers = {
+    'Authorization': 'Bearer ' + userToken
+    }
+
+    response = requests.request("GET", url, headers=headers, data=payload)
+    getCode = response.status_code
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        parseResponse = json.loads(response.text)
+        return(parseResponse)
+    else:
+        print("Error: " + str(getCode))
+        return(getCode)
+    
+# Print iterations progress
+def printProgressBar (iteration, total, prefix = '', suffix = '', decimals = 1, length = 100, fill = '█', printEnd = "\n"):
+    """
+    Call in a loop to create terminal progress bar
+    @params:
+        iteration   - Required  : current iteration (Int)
+        total       - Required  : total iterations (Int)
+        prefix      - Optional  : prefix string (Str)
+        suffix      - Optional  : suffix string (Str)
+        decimals    - Optional  : positive number of decimals in percent complete (Int)
+        length      - Optional  : character length of bar (Int)
+        fill        - Optional  : bar fill character (Str)
+        printEnd    - Optional  : end character (e.g. "\r", "\r\n") (Str)
+    """
+    percent = ("{0:." + str(decimals) + "f}").format(100 * (iteration / float(total)))
+    filledLength = int(length * iteration // total)
+    bar = fill * filledLength + '-' * (length - filledLength)
+    print(f'{prefix} |{bar}| {percent}% {suffix}', end = printEnd)
 
-    #print(parseResponse)
-    return nodes
-    #self.isComplete = parseResponse["isComplete"]
 
 def batchSimulation(queue, allNodes, userID,token):
 
@@ -459,17 +584,16 @@ def batchSimulation(queue, allNodes, userID,token):
         #runningNodes = activeSimulationNodes(3,token)
         for item in range(len(queue)):
             if (queue[item].hasStarted == True and queue[item].isComplete == False):
-                print('JOB INPROGRESS: simulation ' + str(queue[item].simID) + ' is running.')
-                queue[item].getProgress()
-                print('-------------')
-
+                print('\033[2KSimulation [' + str(queue[item].simID) + '] : ', end='')
+                printProgressBar(queue[item].getProgress(), 100, prefix='Running', length=50)
+                    
             if (queue[item].hasStarted == True and queue[item].isComplete == True):
-                print('UPDATE: simulation ' + str(queue[item].simID) + ' is complete.')
-                print('-------------')
-
+                print('\033[2KSimulation [' + str(queue[item].simID) + '] : Complete')
+                    
             if (queue[item].hasStarted == False and queue[item].isComplete == False):
-                print('UPDATE: simulation ' + str(queue[item].simID) + ' has not yet started.')
-                print('-------------')  
+                print('\033[2KSimulation [' + str(queue[item].simID) + '] : Not yet started')
+
+        print('\033['+str(len(queue)+1)+'A')
 
         for item in range(len(queue)):
             time.sleep(5)
@@ -482,4 +606,41 @@ def batchSimulation(queue, allNodes, userID,token):
             state[item]=queue[item].hasStarted
             x = all(state)
 
-    print("All simulations in queue have been started.")
\ No newline at end of file
+    for item in range(len(queue)):
+        if (queue[item].hasStarted == True and queue[item].isComplete == False):
+            print('\033[2KSimulation [' + str(queue[item].simID) + '] : ', end='')
+            printProgressBar(queue[item].getProgress(), 100, prefix='Running', length=50)
+                
+        if (queue[item].hasStarted == True and queue[item].isComplete == True):
+            print('\033[2KSimulation [' + str(queue[item].simID) + '] : Complete')
+                
+        if (queue[item].hasStarted == False and queue[item].isComplete == False):
+            print('\033[2KSimulation [' + str(queue[item].simID) + '] : Not yet started')
+
+    print("All simulations in queue have been started.")
+
+def getOrganizationSimulations(orgID,state,token):
+
+    # //Possible States
+    # // RUNNING
+    # // COMPLETED
+    # // CREATED
+
+    url = "https://lexsetapi.lexset.ai/api/Simulations/GetSimulationsByOrganization?orgid=" + (str(orgID)) +"&state=" + state
+
+    payload={}
+    headers = {
+    'Authorization': 'Bearer ' + token
+    }
+
+    response = requests.request("GET", url, headers=headers, data=payload)
+    getCode = response.status_code
+
+    if getCode == 401:
+        return("Unauthorized")
+    if getCode == 200:
+        parseResponse = json.loads(response.text)
+        return(parseResponse)
+    else:
+        print("Error: " + str(getCode))
+        return(getCode)
